==> 3.3.1.tar.gz: test/longlog.dart <==
import 'package:test/test.dart';
import 'package:yona/yona.dart';

var host = NetAddr.fromString("yonafediverse.com:7777");

void main() async {
  test("test longlog", () async {
    List<int> user1;
    while(true) {
      user1 = await Crypto.genSK();
      var packets = await Longlog.pull(host, Packet(
          Crypto.derivePK(user1), List.filled(Packet.pkSize, 0), [],
          Packet.zeroID).encode(), 10,Duration(seconds: 3));
      if(packets.isEmpty){
        break;
      }
    }
    List<int> user2;
    while(true) {
      user2 = await Crypto.genSK();
      var packets = await Longlog.pull(host, Packet(
          Crypto.derivePK(user1), List.filled(Packet.pkSize, 0), [],
          Packet.zeroID).encode(), 10,Duration(seconds: 3));
      if(packets.isEmpty){
        break;
      }
    }
    var packet1 = Packet(Crypto.derivePK(user1),Crypto.derivePK(user2),await Crypto.randBytes(100),Packet.zeroID);
    var packet2 = Packet(Crypto.derivePK(user2),Crypto.derivePK(user1),await Crypto.randBytes(100),Packet.zeroID);
    await Longlog.push(host, packet1.encode(), user2, Duration(seconds: 2));
    await Longlog.push(host, packet2.encode(), user1, Duration(seconds: 2));
    var packets = await Longlog.pull(host, Packet(Crypto.derivePK(user1),List.filled(Packet.pkSize, 0),[],Packet.zeroID).encode(), 10,Duration(seconds: 3));
    assert(packets.length == 1);
    assert(Utils.equal(packets[0].data,packet1.data));
    assert(Utils.equal(packets[0].from,packet1.from));
    assert(Utils.equal(packets[0].to,packet1.to));
    packets = await Longlog.pull(host, packets[0].encode(), 10,Duration(seconds: 3));
    assert(packets.isEmpty);
    packets = await Longlog.pull(host, Packet(Crypto.derivePK(user2),List.filled(Packet.pkSize, 0),[],Packet.zeroID).encode(), 10,Duration(seconds: 3));
    assert(packets.length == 1);
    assert(Utils.equal(packets[0].data,packet2.data));
    assert(Utils.equal(packets[0].from,packet2.from));
    assert(Utils.equal(packets[0].to,packet2.to));
    packets = await Longlog.pull(host, packets[0].encode(), 10,Duration(seconds: 3));
    assert(packets.isEmpty);
  });
}

==> 3.5.1.tar.gz: test/longlog.dart <==
import 'package:test/test.dart';
import 'package:yona/yona.dart';

var host = NetAddr.fromString("yonafediverse.com:7777");

void main() async {
  test("test longlog", () async {
    List<int> user1;
    while(true) {
      user1 = await Crypto.genSK();
      var packets = await Longlog.pull(host, Packet(
          Crypto.derivePK(user1), List.filled(Packet.pkSize, 0), [],
          Packet.zeroID).encode(), 10,Duration(seconds: 3));
      if(packets.isEmpty){
        break;
      }
    }
    List<int> user2;
    while(true) {
      user2 = await Crypto.genSK();
      var packets = await Longlog.pull(host, Packet(
          Crypto.derivePK(user1), List.filled(Packet.pkSize, 0), [],
          Packet.zeroID).encode(), 10,Duration(seconds: 3));
      if(packets.isEmpty){
        break;
      }
    }
    var packet1 = Packet(Crypto.derivePK(user1),Crypto.derivePK(user2),await Crypto.randBytes(100),Packet.zeroID);
    var packet2 = Packet(Crypto.derivePK(user2),Crypto.derivePK(user1),await Crypto.randBytes(100),Packet.zeroID);
    await Longlog.push(host, packet1.encode(), user2, Duration(seconds: 2),Duration(minutes: 10));
    await Longlog.push(host, packet2.encode(), user1, Duration(seconds: 2),Duration(minutes: 2));
    var packets = await Longlog.pull(host, Packet(Crypto.derivePK(user1),List.filled(Packet.pkSize, 0),[],Packet.zeroID).encode(), 10,Duration(seconds: 3));
    assert(packets.length == 1);
    assert(Utils.equal(packets[0].data,packet1.data));
    assert(Utils.equal(packets[0].from,packet1.from));
    assert(Utils.equal(packets[0].to,packet1.to));
    packets = await Longlog.pull(host, packets[0].encode(), 10,Duration(seconds: 3));
    assert(packets.isEmpty);
    packets = await Longlog.pull(host, Packet(Crypto.derivePK(user2),List.filled(Packet.pkSize, 0),[],Packet.zeroID).encode(), 10,Duration(seconds: 3));
    assert(packets.length == 1);
    assert(Utils.equal(packets[0].data,packet2.data));
    assert(Utils.equal(packets[0].from,packet2.from));
    assert(Utils.equal(packets[0].to,packet2.to));
    packets = await Longlog.pull(host, packets[0].encode(), 10,Duration(seconds: 3));
    assert(packets.isEmpty);
  });
}
